@@ -1,6 +1,8 @@
 package Slovo::Validator;
 use Mojo::Base 'Mojolicious::Validator';
-
+use feature qw(lexical_subs unicode_strings);
+## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+no warnings "experimental::lexical_subs";
 
 has filters => sub {
   +{
