@@ -71,7 +71,7 @@ function get_страници ($url, $parent) {
         }
         $('<ul>').appendTo($parent);
         $data.forEach(function($row){
-            let $page_url = `/${$row.alias}.стр.html`;
+            let $page_url = `/${$row.alias}.html`;
             let $page_link = `<a href="${$page_url}">${$row.title}</a>`;
             let $expander_url = '',
                 $expander_link =  '',
